@@ -18,11 +18,11 @@ Queue::DBI - A queueing module with an emphasis on safety, using DBI as a storag
 
 =head1 VERSION
 
-Version 2.4.2
+Version 2.5.0
 
 =cut
 
-our $VERSION = '2.4.2';
+our $VERSION = '2.5.0';
 
 our $DEFAULT_QUEUES_TABLE_NAME = 'queues';
 
@@ -202,21 +202,30 @@ sub new
 	);
 	
 	# Find the queue id.
-	my @queue = $dbh->selectrow_array(
-		sprintf(
-			q|
-				SELECT queue_id
-				FROM %s
-				WHERE name = ?
-			|,
-			$dbh->quote_identifier( $self->get_queues_table_name() ),
-		),
-		{},
-		$args{'queue_name'},
-	);
+	my $queue_id;
+	{
+		local $dbh->{'RaiseError'} = 1;
+		my $data = $dbh->selectrow_arrayref(
+			sprintf(
+				q|
+					SELECT queue_id
+					FROM %s
+					WHERE name = ?
+				|,
+				$dbh->quote_identifier( $self->get_queues_table_name() ),
+			),
+			{},
+			$args{'queue_name'},
+		);
+		
+		$queue_id = defined( $data ) && scalar( @$data ) != 0
+			? $data->[0]
+			: undef;
+	}
+	
 	croak "The queue >$args{'queue_name'}< doesn't exist in the lookup table."
-		unless defined( $queue[0] ) && ( $queue[0] =~ m/^\d+$/ );
-	$self->{'queue_id'} = $queue[0];
+		unless defined( $queue_id ) && ( $queue_id =~ m/^\d+$/ );
+	$self->{'queue_id'} = $queue_id;
 	
 	# Set optional parameters.
 	$self->set_verbose( $args{'verbose'} );
@@ -284,22 +293,27 @@ sub count
 		: '';
 	
 	# Count elements.
-	my $data = $dbh->selectrow_arrayref(
-		sprintf(
-			q|
-				SELECT COUNT(*)
-				FROM %s
-				WHERE queue_id = ?
-					%s
-			|,
-			$dbh->quote_identifier( $self->get_queue_elements_table_name() ),
-			$exclude_locked_elements_sql,
-		),
-		{},
-		$self->get_queue_id(),
-	) || croak 'Cannot execute SQL: ' . $dbh->errstr();
-	
-	my $element_count = defined( $data ) && defined( $data->[0] ) ? $data->[0] : 0;
+	my $element_count;
+	{
+		local $dbh->{'RaiseError'} = 1;
+		my $data = $dbh->selectrow_arrayref(
+			sprintf(
+				q|
+					SELECT COUNT(*)
+					FROM %s
+					WHERE queue_id = ?
+						%s
+				|,
+				$dbh->quote_identifier( $self->get_queue_elements_table_name() ),
+				$exclude_locked_elements_sql,
+			),
+			{},
+			$self->get_queue_id(),
+		);
+		$element_count = defined( $data ) && scalar( @$data ) != 0 && defined( $data->[0] )
+			? $data->[0]
+			: 0;
+	}
 	
 	carp "Found $element_count elements, leaving count()." if $verbose;
 	
@@ -440,22 +454,30 @@ sub retrieve_batch
 	# Prevent infinite loops
 	unless ( defined( $self->{'max_id'} ) )
 	{
-		my $data = $dbh->selectrow_arrayref(
-			sprintf(
-				q|
-					SELECT MAX(queue_element_id)
-					FROM %s
-					WHERE queue_id = ?
-				|,
-				$dbh->quote_identifier( $self->get_queue_elements_table_name() ),
-			),
-			{},
-			$self->get_queue_id(),
-		);
-		croak 'Cannot execute SQL: ' . $dbh->errstr() if defined( $dbh->errstr() );
-		if ( defined( $data ) && defined( $data->[0] ) )
+		my $max_id;
 		{
-			$self->{'max_id'} = $data->[0];
+			local $dbh->{'RaiseError'} = 1;
+			my $data = $dbh->selectrow_arrayref(
+				sprintf(
+					q|
+						SELECT MAX(queue_element_id)
+						FROM %s
+						WHERE queue_id = ?
+					|,
+					$dbh->quote_identifier( $self->get_queue_elements_table_name() ),
+				),
+				{},
+				$self->get_queue_id(),
+			);
+			
+			$max_id = defined( $data ) && scalar( @$data ) != 0
+				? $data->[0]
+				: undef;
+		}
+		
+		if ( defined( $max_id ) )
+		{
+			$self->{'max_id'} = $max_id;
 		}
 		else
 		{
